==> php-nesbot-carbon_2.32.2.orig.tar.xz: php-nesbot-carbon-2.32.2/tests/Localization/DzBtTest.php <==
<?php
declare(strict_types=1);

/**
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace Tests\Localization;

class DzBtTest extends LocalizationTestCase
{
    const LOCALE = 'dz_BT'; // Dzongkha

    const CASES = [
        // Carbon::parse('2018-01-04 00:00:00')->addDays(1)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Tomorrow at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'གཟའ་ཉི་མ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(3)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'གཟའ་ཟླ་བ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(4)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'གཟའ་མིག་དམར་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(5)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'གཟའ་ལྷག་ཕ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'གཟའ་པུར་བུ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-05 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-05 00:00:00'))
        'གཟའ་པ་སངས་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-06 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-06 00:00:00'))
        'གཟའ་སྤེན་ཕ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'གཟའ་ལྷག་ཕ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(3)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'གཟའ་པུར་བུ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(4)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'གཟའ་པ་སངས་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(5)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'གཟའ་སྤེན་ཕ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'གཟའ་ཉི་མ་ at 12:00 ངས་ཆ',
        // Carbon::now()->subDays(2)->calendar()
        'Last གཟའ་ཟླ་བ་ at 8:49 ཕྱི་ཆ',
        // Carbon::parse('2018-01-04 00:00:00')->subHours(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Yesterday at 10:00 ཕྱི་ཆ',
        // Carbon::parse('2018-01-04 12:00:00')->subHours(2)->calendar(Carbon::parse('2018-01-04 12:00:00'))
        'Today at 10:00 ངས་ཆ',
        // Carbon::parse('2018-01-04 00:00:00')->addHours(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Today at 2:00 ངས་ཆ',
        // Carbon::parse('2018-01-04 23:00:00')->addHours(2)->calendar(Carbon::parse('2018-01-04 23:00:00'))
        'Tomorrow at 1:00 ངས་ཆ',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'གཟའ་ལྷག་ཕ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-08 00:00:00')->subDay()->calendar(Carbon::parse('2018-01-08 00:00:00'))
        'Yesterday at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(1)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Yesterday at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last གཟའ་ལྷག་ཕ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(3)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last གཟའ་མིག་དམར་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(4)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last གཟའ་ཟླ་བ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(5)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last གཟའ་ཉི་མ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last གཟའ་སྤེན་ཕ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-03 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-03 00:00:00'))
        'Last གཟའ་པ་སངས་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-02 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-02 00:00:00'))
        'Last གཟའ་པུར་བུ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-07 00:00:00')->subDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'Last གཟའ་སྤེན་ཕ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-01 00:00:00')->isoFormat('Qo Mo Do Wo wo')
        '1st 1st 1st 1st 1st',
        // Carbon::parse('2018-01-02 00:00:00')->isoFormat('Do wo')
        '2nd 1st',
        // Carbon::parse('2018-01-03 00:00:00')->isoFormat('Do wo')
        '3rd 1st',
        // Carbon::parse('2018-01-04 00:00:00')->isoFormat('Do wo')
        '4th 1st',
        // Carbon::parse('2018-01-05 00:00:00')->isoFormat('Do wo')
        '5th 1st',
        // Carbon::parse('2018-01-06 00:00:00')->isoFormat('Do wo')
        '6th 1st',
        // Carbon::parse('2018-01-07 00:00:00')->isoFormat('Do wo')
        '7th 2nd',
        // Carbon::parse('2018-01-11 00:00:00')->isoFormat('Do wo')
        '11th 2nd',
        // Carbon::parse('2018-02-09 00:00:00')->isoFormat('DDDo')
        '40th',
        // Carbon::parse('2018-02-10 00:00:00')->isoFormat('DDDo')
        '41st',
        // Carbon::parse('2018-04-10 00:00:00')->isoFormat('DDDo')
        '100th',
        // Carbon::parse('2018-02-10 00:00:00', 'Europe/Paris')->isoFormat('h:mm a z')
        '12:00 ངས་ཆ CET',
        // Carbon::parse('2018-02-10 00:00:00')->isoFormat('h:mm A, h:mm a')
        '12:00 ངས་ཆ, 12:00 ངས་ཆ',
        // Carbon::parse('2018-02-10 01:30:00')->isoFormat('h:mm A, h:mm a')
        '1:30 ངས་ཆ, 1:30 ངས་ཆ',
        // Carbon::parse('2018-02-10 02:00:00')->isoFormat('h:mm A, h:mm a')
        '2:00 ངས་ཆ, 2:00 ངས་ཆ',
        // Carbon::parse('2018-02-10 06:00:00')->isoFormat('h:mm A, h:mm a')
        '6:00 ངས་ཆ, 6:00 ངས་ཆ',
        // Carbon::parse('2018-02-10 10:00:00')->isoFormat('h:mm A, h:mm a')
        '10:00 ངས་ཆ, 10:00 ངས་ཆ',
        // Carbon::parse('2018-02-10 12:00:00')->isoFormat('h:mm A, h:mm a')
        '12:00 ཕྱི་ཆ, 12:00 ཕྱི་ཆ',
        // Carbon::parse('2018-02-10 17:00:00')->isoFormat('h:mm A, h:mm a')
        '5:00 ཕྱི་ཆ, 5:00 ཕྱི་ཆ',
        // Carbon::parse('2018-02-10 21:30:00')->isoFormat('h:mm A, h:mm a')
        '9:30 ཕྱི་ཆ, 9:30 ཕྱི་ཆ',
        // Carbon::parse('2018-02-10 23:00:00')->isoFormat('h:mm A, h:mm a')
        '11:00 ཕྱི་ཆ, 11:00 ཕྱི་ཆ',
        // Carbon::parse('2018-01-01 00:00:00')->ordinal('hour')
        '0th',
        // Carbon::now()->subSeconds(1)->diffForHumans()
        '1 ཆ ago',
        // Carbon::now()->subSeconds(1)->diffForHumans(null, false, true)
        '1 ཆ ago',
        // Carbon::now()->subSeconds(2)->diffForHumans()
        '2 ཆ ago',
        // Carbon::now()->subSeconds(2)->diffForHumans(null, false, true)
        '2 ཆ ago',
        // Carbon::now()->subMinutes(1)->diffForHumans()
        '1 minute ago',
        // Carbon::now()->subMinutes(1)->diffForHumans(null, false, true)
        '1m ago',
        // Carbon::now()->subMinutes(2)->diffForHumans()
        '2 minutes ago',
        // Carbon::now()->subMinutes(2)->diffForHumans(null, false, true)
        '2m ago',
        // Carbon::now()->subHours(1)->diffForHumans()
        '1 hour ago',
        // Carbon::now()->subHours(1)->diffForHumans(null, false, true)
        '1h ago',
        // Carbon::now()->subHours(2)->diffForHumans()
        '2 hours ago',
        // Carbon::now()->subHours(2)->diffForHumans(null, false, true)
        '2h ago',
        // Carbon::now()->subDays(1)->diffForHumans()
        '1 ཉི ago',
        // Carbon::now()->subDays(1)->diffForHumans(null, false, true)
        '1 ཉི ago',
        // Carbon::now()->subDays(2)->diffForHumans()
        '2 ཉི ago',
        // Carbon::now()->subDays(2)->diffForHumans(null, false, true)
        '2 ཉི ago',
        // Carbon::now()->subWeeks(1)->diffForHumans()
        '1 week ago',
        // Carbon::now()->subWeeks(1)->diffForHumans(null, false, true)
        '1w ago',
        // Carbon::now()->subWeeks(2)->diffForHumans()
        '2 weeks ago',
        // Carbon::now()->subWeeks(2)->diffForHumans(null, false, true)
        '2w ago',
        // Carbon::now()->subMonths(1)->diffForHumans()
        '1 ཟླ་བ ago',
        // Carbon::now()->subMonths(1)->diffForHumans(null, false, true)
        '1 ཟླ་བ ago',
        // Carbon::now()->subMonths(2)->diffForHumans()
        '2 ཟླ་བ ago',
        // Carbon::now()->subMonths(2)->diffForHumans(null, false, true)
        '2 ཟླ་བ ago',
        // Carbon::now()->subYears(1)->diffForHumans()
        '1 ཆརཔ ago',
        // Carbon::now()->subYears(1)->diffForHumans(null, false, true)
        '1 ཆརཔ ago',
        // Carbon::now()->subYears(2)->diffForHumans()
        '2 ཆརཔ ago',
        // Carbon::now()->subYears(2)->diffForHumans(null, false, true)
        '2 ཆརཔ ago',
        // Carbon::now()->addSecond()->diffForHumans()
        '1 ཆ from now',
        // Carbon::now()->addSecond()->diffForHumans(null, false, true)
        '1 ཆ from now',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now())
        '1 ཆ after',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), false, true)
        '1 ཆ after',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond())
        '1 ཆ before',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond(), false, true)
        '1 ཆ before',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), true)
        '1 ཆ',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), true, true)
        '1 ཆ',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond()->addSecond(), true)
        '2 ཆ',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond()->addSecond(), true, true)
        '2 ཆ',
        // Carbon::now()->addSecond()->diffForHumans(null, false, true, 1)
        '1 ཆ from now',
        // Carbon::now()->addMinute()->addSecond()->diffForHumans(null, true, false, 2)
        '1 minute 1 ཆ',
        // Carbon::now()->addYears(2)->addMonths(3)->addDay()->addSecond()->diffForHumans(null, true, true, 4)
        '2 ཆརཔ 3 ཟླ་བ 1 ཉི 1 ཆ',
        // Carbon::now()->addYears(3)->diffForHumans(null, null, false, 4)
        '3 ཆརཔ from now',
        // Carbon::now()->subMonths(5)->diffForHumans(null, null, true, 4)
        '5 ཟླ་བ ago',
        // Carbon::now()->subYears(2)->subMonths(3)->subDay()->subSecond()->diffForHumans(null, null, true, 4)
        '2 ཆརཔ 3 ཟླ་བ 1 ཉི 1 ཆ ago',
        // Carbon::now()->addWeek()->addHours(10)->diffForHumans(null, true, false, 2)
        '1 week 10 hours',
        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(null, true, false, 2)
        '1 week 6 ཉི',
        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(null, true, false, 2)
        '1 week 6 ཉི',
        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(["join" => true, "parts" => 2])
        '1 week and 6 ཉི from now',
        // Carbon::now()->addWeeks(2)->addHour()->diffForHumans(null, true, false, 2)
        '2 weeks 1 hour',
        // Carbon::now()->addHour()->diffForHumans(["aUnit" => true])
        'an hour from now',
        // CarbonInterval::days(2)->forHumans()
        '2 ཉི',
        // CarbonInterval::create('P1DT3H')->forHumans(true)
        '1 ཉི 3h',
    ];
}

==> php-nesbot-carbon_2.73.0.orig.tar.xz: php-nesbot-carbon-2.73.0/tests/Localization/DzBtTest.php <==
<?php

declare(strict_types=1);

/**
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Tests\Localization;

/**
 * @group localization
 */
class DzBtTest extends LocalizationTestCase
{
    public const LOCALE = 'dz_BT'; // Dzongkha

    public const CASES = [
        // Carbon::parse('2018-01-04 00:00:00')->addDays(1)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Tomorrow at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'གཟའ་ཉི་མ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(3)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'གཟའ་ཟླ་བ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(4)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'གཟའ་མིག་དམར་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(5)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'གཟའ་ལྷག་ཕ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'གཟའ་པུར་བུ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-05 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-05 00:00:00'))
        'གཟའ་པ་སངས་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-06 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-06 00:00:00'))
        'གཟའ་སྤེན་ཕ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'གཟའ་ལྷག་ཕ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(3)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'གཟའ་པུར་བུ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(4)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'གཟའ་པ་སངས་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(5)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'གཟའ་སྤེན་ཕ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'གཟའ་ཉི་མ་ at 12:00 ངས་ཆ',
        // Carbon::now()->subDays(2)->calendar()
        'Last གཟའ་ཟླ་བ་ at 8:49 ཕྱི་ཆ',
        // Carbon::parse('2018-01-04 00:00:00')->subHours(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Yesterday at 10:00 ཕྱི་ཆ',
        // Carbon::parse('2018-01-04 12:00:00')->subHours(2)->calendar(Carbon::parse('2018-01-04 12:00:00'))
        'Today at 10:00 ངས་ཆ',
        // Carbon::parse('2018-01-04 00:00:00')->addHours(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Today at 2:00 ངས་ཆ',
        // Carbon::parse('2018-01-04 23:00:00')->addHours(2)->calendar(Carbon::parse('2018-01-04 23:00:00'))
        'Tomorrow at 1:00 ངས་ཆ',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'གཟའ་ལྷག་ཕ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-08 00:00:00')->subDay()->calendar(Carbon::parse('2018-01-08 00:00:00'))
        'Yesterday at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(1)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Yesterday at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last གཟའ་ལྷག་ཕ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(3)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last གཟའ་མིག་དམར་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(4)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last གཟའ་ཟླ་བ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(5)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last གཟའ་ཉི་མ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last གཟའ་སྤེན་ཕ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-03 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-03 00:00:00'))
        'Last གཟའ་པ་སངས་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-02 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-02 00:00:00'))
        'Last གཟའ་པུར་བུ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-07 00:00:00')->subDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'Last གཟའ་སྤེན་ཕ་ at 12:00 ངས་ཆ',
        // Carbon::parse('2018-01-01 00:00:00')->isoFormat('Qo Mo Do Wo wo')
        '1st 1st 1st 1st 1st',
        // Carbon::parse('2018-01-02 00:00:00')->isoFormat('Do wo')
        '2nd 1st',
        // Carbon::parse('2018-01-03 00:00:00')->isoFormat('Do wo')
        '3rd 1st',
        // Carbon::parse('2018-01-04 00:00:00')->isoFormat('Do wo')
        '4th 1st',
        // Carbon::parse('2018-01-05 00:00:00')->isoFormat('Do wo')
        '5th 1st',
        // Carbon::parse('2018-01-06 00:00:00')->isoFormat('Do wo')
        '6th 1st',
        // Carbon::parse('2018-01-07 00:00:00')->isoFormat('Do wo')
        '7th 2nd',
        // Carbon::parse('2018-01-11 00:00:00')->isoFormat('Do wo')
        '11th 2nd',
        // Carbon::parse('2018-02-09 00:00:00')->isoFormat('DDDo')
        '40th',
        // Carbon::parse('2018-02-10 00:00:00')->isoFormat('DDDo')
        '41st',
        // Carbon::parse('2018-04-10 00:00:00')->isoFormat('DDDo')
        '100th',
        // Carbon::parse('2018-02-10 00:00:00', 'Europe/Paris')->isoFormat('h:mm a z')
        '12:00 ངས་ཆ CET',
        // Carbon::parse('2018-02-10 00:00:00')->isoFormat('h:mm A, h:mm a')
        '12:00 ངས་ཆ, 12:00 ངས་ཆ',
        // Carbon::parse('2018-02-10 01:30:00')->isoFormat('h:mm A, h:mm a')
        '1:30 ངས་ཆ, 1:30 ངས་ཆ',
        // Carbon::parse('2018-02-10 02:00:00')->isoFormat('h:mm A, h:mm a')
        '2:00 ངས་ཆ, 2:00 ངས་ཆ',
        // Carbon::parse('2018-02-10 06:00:00')->isoFormat('h:mm A, h:mm a')
        '6:00 ངས་ཆ, 6:00 ངས་ཆ',
        // Carbon::parse('2018-02-10 10:00:00')->isoFormat('h:mm A, h:mm a')
        '10:00 ངས་ཆ, 10:00 ངས་ཆ',
        // Carbon::parse('2018-02-10 12:00:00')->isoFormat('h:mm A, h:mm a')
        '12:00 ཕྱི་ཆ, 12:00 ཕྱི་ཆ',
        // Carbon::parse('2018-02-10 17:00:00')->isoFormat('h:mm A, h:mm a')
        '5:00 ཕྱི་ཆ, 5:00 ཕྱི་ཆ',
        // Carbon::parse('2018-02-10 21:30:00')->isoFormat('h:mm A, h:mm a')
        '9:30 ཕྱི་ཆ, 9:30 ཕྱི་ཆ',
        // Carbon::parse('2018-02-10 23:00:00')->isoFormat('h:mm A, h:mm a')
        '11:00 ཕྱི་ཆ, 11:00 ཕྱི་ཆ',
        // Carbon::parse('2018-01-01 00:00:00')->ordinal('hour')
        '0th',
        // Carbon::now()->subSeconds(1)->diffForHumans()
        '1 ཆ ago',
        // Carbon::now()->subSeconds(1)->diffForHumans(null, false, true)
        '1 ཆ ago',
        // Carbon::now()->subSeconds(2)->diffForHumans()
        '2 ཆ ago',
        // Carbon::now()->subSeconds(2)->diffForHumans(null, false, true)
        '2 ཆ ago',
        // Carbon::now()->subMinutes(1)->diffForHumans()
        '1 minute ago',
        // Carbon::now()->subMinutes(1)->diffForHumans(null, false, true)
        '1m ago',
        // Carbon::now()->subMinutes(2)->diffForHumans()
        '2 minutes ago',
        // Carbon::now()->subMinutes(2)->diffForHumans(null, false, true)
        '2m ago',
        // Carbon::now()->subHours(1)->diffForHumans()
        '1 hour ago',
        // Carbon::now()->subHours(1)->diffForHumans(null, false, true)
        '1h ago',
        // Carbon::now()->subHours(2)->diffForHumans()
        '2 hours ago',
        // Carbon::now()->subHours(2)->diffForHumans(null, false, true)
        '2h ago',
        // Carbon::now()->subDays(1)->diffForHumans()
        '1 ཉི ago',
        // Carbon::now()->subDays(1)->diffForHumans(null, false, true)
        '1 ཉི ago',
        // Carbon::now()->subDays(2)->diffForHumans()
        '2 ཉི ago',
        // Carbon::now()->subDays(2)->diffForHumans(null, false, true)
        '2 ཉི ago',
        // Carbon::now()->subWeeks(1)->diffForHumans()
        '1 week ago',
        // Carbon::now()->subWeeks(1)->diffForHumans(null, false, true)
        '1w ago',
        // Carbon::now()->subWeeks(2)->diffForHumans()
        '2 weeks ago',
        // Carbon::now()->subWeeks(2)->diffForHumans(null, false, true)
        '2w ago',
        // Carbon::now()->subMonths(1)->diffForHumans()
        '1 ཟླ་བ ago',
        // Carbon::now()->subMonths(1)->diffForHumans(null, false, true)
        '1 ཟླ་བ ago',
        // Carbon::now()->subMonths(2)->diffForHumans()
        '2 ཟླ་བ ago',
        // Carbon::now()->subMonths(2)->diffForHumans(null, false, true)
        '2 ཟླ་བ ago',
        // Carbon::now()->subYears(1)->diffForHumans()
        '1 ཆརཔ ago',
        // Carbon::now()->subYears(1)->diffForHumans(null, false, true)
        '1 ཆརཔ ago',
        // Carbon::now()->subYears(2)->diffForHumans()
        '2 ཆརཔ ago',
        // Carbon::now()->subYears(2)->diffForHumans(null, false, true)
        '2 ཆརཔ ago',
        // Carbon::now()->addSecond()->diffForHumans()
        '1 ཆ from now',
        // Carbon::now()->addSecond()->diffForHumans(null, false, true)
        '1 ཆ from now',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now())
        '1 ཆ after',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), false, true)
        '1 ཆ after',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond())
        '1 ཆ before',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond(), false, true)
        '1 ཆ before',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), true)
        '1 ཆ',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), true, true)
        '1 ཆ',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond()->addSecond(), true)
        '2 ཆ',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond()->addSecond(), true, true)
        '2 ཆ',
        // Carbon::now()->addSecond()->diffForHumans(null, false, true, 1)
        '1 ཆ from now',
        // Carbon::now()->addMinute()->addSecond()->diffForHumans(null, true, false, 2)
        '1 minute 1 ཆ',
        // Carbon::now()->addYears(2)->addMonths(3)->addDay()->addSecond()->diffForHumans(null, true, true, 4)
        '2 ཆརཔ 3 ཟླ་བ 1 ཉི 1 ཆ',
        // Carbon::now()->addYears(3)->diffForHumans(null, null, false, 4)
        '3 ཆརཔ from now',
        // Carbon::now()->subMonths(5)->diffForHumans(null, null, true, 4)
        '5 ཟླ་བ ago',
        // Carbon::now()->subYears(2)->subMonths(3)->subDay()->subSecond()->diffForHumans(null, null, true, 4)
        '2 ཆརཔ 3 ཟླ་བ 1 ཉི 1 ཆ ago',
        // Carbon::now()->addWeek()->addHours(10)->diffForHumans(null, true, false, 2)
        '1 week 10 hours',
        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(null, true, false, 2)
        '1 week 6 ཉི',
        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(null, true, false, 2)
        '1 week 6 ཉི',
        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(["join" => true, "parts" => 2])
        '1 week and 6 ཉི from now',
        // Carbon::now()->addWeeks(2)->addHour()->diffForHumans(null, true, false, 2)
        '2 weeks 1 hour',
        // Carbon::now()->addHour()->diffForHumans(["aUnit" => true])
        'an hour from now',
        // CarbonInterval::days(2)->forHumans()
        '2 ཉི',
        // CarbonInterval::create('P1DT3H')->forHumans(true)
        '1 ཉི 3h',
    ];
}
